@@ -109,6 +109,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -391,6 +392,8 @@ types: list[str] = [
     "AWS::EC2::LocalGatewayRouteTable",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
     "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation",
+    "AWS::EC2::LocalGatewayVirtualInterface",
+    "AWS::EC2::LocalGatewayVirtualInterfaceGroup",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
@@ -828,6 +831,7 @@ types: list[str] = [
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::ObservabilityAdmin::OrganizationCentralizationRule",
     "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
     "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::OpenSearchServerless::AccessPolicy",
@@ -1301,6 +1305,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1613,6 +1618,8 @@ cached: list[str] = [
     "aws-ec2-localgatewayroutetable.json",
     "aws-ec2-localgatewayroutetablevirtualinterfacegroupassociation.json",
     "aws-ec2-localgatewayroutetablevpcassociation.json",
+    "aws-ec2-localgatewayvirtualinterface.json",
+    "aws-ec2-localgatewayvirtualinterfacegroup.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
@@ -1738,6 +1745,7 @@ cached: list[str] = [
     "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-entityresolution-idmappingworkflow.json",
     "aws-entityresolution-idnamespace.json",
     "aws-entityresolution-matchingworkflow.json",
     "aws-entityresolution-policystatement.json",
@@ -1909,6 +1917,7 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -2013,29 +2022,25 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
-    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
-    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
-    "aws-networkmanager-sitetositevpnattachment.json",
-    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
-    "aws-networkmanager-transitgatewayroutetableattachment.json",
-    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-observabilityadmin-organizationcentralizationrule.json",
     "aws-observabilityadmin-organizationtelemetryrule.json",
     "aws-observabilityadmin-telemetryrule.json",
     "aws-opensearchserverless-accesspolicy.json",
@@ -2166,10 +2171,13 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -2256,7 +2264,6 @@ cached: list[str] = [
     "aws-servicecatalog-portfolio.json",
     "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
-    "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
